@@ -38,13 +38,13 @@ class Freebox(IPlugin):
 		entity = jsonInput['outcome']['intent']
 		log.msg("entity :  %s" % (entity))
 		ent = entity[:5]		
-		if ent == "Fb_Ch" :
+		if entity == "Fb_Ch" :
 			on_off = "ONOFF"
 			location = "VIDE"
-		else ent == "Fb_info" :
+		else entity == "Fb_info" :
 			on_off = "ONOFF"
 		#	location = "VIDE"
-		else ent == "Fb_son" :
+		else entity == "Fb_son" :
 		#	on_off = "ONOFF"
 			location = "VIDE"
 #
